.. currentmodule:: cratermaker

.. _api:

#########################
Cratermaker API reference
#########################

This section of the documentation provides a detailed reference for the core functionality and modular components of the Cratermaker project.

.. toctree::
    :maxdepth: 2

    crater
    morphology
    production
    projectile
    scaling
    simulation
    surface
    target
    utils